from tablate.type.primitives import FrameNameList
from tablate.type.type_store import FrameStoreUnion, FrameStoreList


def append_frame_to_list(frame_item: FrameStoreUnion, frame_list: FrameStoreList, frame_name_list: FrameNameList):
    pass
